:orphan:

General
-------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Create a simple histogram of the PMT signals (ToTs) in all events. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_tot_histogram_thumb.png

        :ref:`sphx_glr_auto_examples_plot_tot_histogram.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_tot_histogram

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Sparse Cone ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_sparsecone_thumb.png

        :ref:`sphx_glr_auto_examples_plot_sparsecone.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_sparsecone

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Choosing the right colormap is important. A bad colormap like ``jet`` (standard in ROOT and mat...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_colourmap_pitfalls_thumb.png

        :ref:`sphx_glr_auto_examples_plot_colourmap_pitfalls.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_colourmap_pitfalls

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot the PMT directions for a given DOM.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_pmt_directions_thumb.png

        :ref:`sphx_glr_auto_examples_plot_pmt_directions.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_pmt_directions

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Convex hull of a set of points, representing Dom x-y positions.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_convex_hull_thumb.png

        :ref:`sphx_glr_auto_examples_plot_convex_hull.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_convex_hull

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Estimate track/DOM distances using the number of hits per DOM. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_dom_hits_thumb.png

        :ref:`sphx_glr_auto_examples_plot_dom_hits.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_dom_hits

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_basic_analysis_thumb.png

        :ref:`sphx_glr_auto_examples_plot_basic_analysis.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_basic_analysis
.. raw:: html

    <div style='clear:both'></div>

